@@ -15,12 +15,12 @@ limitations under the License.
 """
 
 from langtrace.trace_attributes import DatabaseSpanAttributes
-from langtrace_python_sdk.utils.llm import set_span_attributes
+from langtrace_python_sdk.utils import set_span_attribute
 from langtrace_python_sdk.utils.silently_fail import silently_fail
-from opentelemetry import baggage
+from opentelemetry import baggage, trace
 from opentelemetry.trace import SpanKind
 from opentelemetry.trace.status import Status, StatusCode
-
+from opentelemetry.trace.propagation import set_span_in_context
 from langtrace_python_sdk.constants.instrumentation.chroma import APIS
 from langtrace_python_sdk.constants.instrumentation.common import (
     LANGTRACE_ADDITIONAL_SPAN_ATTRIBUTES_KEY,
@@ -59,7 +59,11 @@ def collection_patch(method, version, tracer):
 
         attributes = DatabaseSpanAttributes(**span_attributes)
 
-        with tracer.start_as_current_span(api["METHOD"], kind=SpanKind.CLIENT) as span:
+        with tracer.start_as_current_span(
+            api["METHOD"],
+            kind=SpanKind.CLIENT,
+            context=set_span_in_context(trace.get_current_span()),
+        ) as span:
             for field, value in attributes.model_dump(by_alias=True).items():
                 if value is not None:
                     span.set_attribute(field, value)
@@ -115,20 +119,20 @@ def handle_null_params(param):
 
 @silently_fail
 def _set_chroma_add_attributes(span, kwargs):
-    set_span_attributes(
+    set_span_attribute(
         span, "db.chroma.add.ids_count", get_count_or_none(kwargs.get("ids"))
     )
-    set_span_attributes(
+    set_span_attribute(
         span,
         "db.chroma.add.embeddings_count",
         get_count_or_none(kwargs.get("embeddings")),
     )
-    set_span_attributes(
+    set_span_attribute(
         span,
         "db.chroma.add.metadatas_count",
         get_count_or_none(kwargs.get("metadatas")),
     )
-    set_span_attributes(
+    set_span_attribute(
         span,
         "db.chroma.add.documents_count",
         get_count_or_none(kwargs.get("documents")),
@@ -137,71 +141,71 @@ def _set_chroma_add_attributes(span, kwargs):
 
 @silently_fail
 def _set_chroma_get_attributes(span, kwargs):
-    set_span_attributes(
+    set_span_attribute(
         span, "db.chroma.get.ids_count", get_count_or_none(kwargs.get("ids"))
     )
-    set_span_attributes(
+    set_span_attribute(
         span, "db.chroma.get.where", handle_null_params(kwargs.get("where"))
     )
-    set_span_attributes(span, "db.chroma.get.limit", kwargs.get("limit"))
-    set_span_attributes(span, "db.chroma.get.offset", kwargs.get("offset"))
-    set_span_attributes(
+    set_span_attribute(span, "db.chroma.get.limit", kwargs.get("limit"))
+    set_span_attribute(span, "db.chroma.get.offset", kwargs.get("offset"))
+    set_span_attribute(
         span,
         "db.chroma.get.where_document",
         handle_null_params(kwargs.get("where_document")),
     )
-    set_span_attributes(
+    set_span_attribute(
         span, "db.chroma.get.include", handle_null_params(kwargs.get("include"))
     )
 
 
 @silently_fail
 def _set_chroma_query_attributes(span, kwargs):
-    set_span_attributes(
+    set_span_attribute(
         span,
         "db.chroma.query.query_embeddings_count",
         get_count_or_none(kwargs.get("query_embeddings")),
     )
-    set_span_attributes(
+    set_span_attribute(
         span,
         "db.chroma.query.query_texts_count",
         get_count_or_none(kwargs.get("query_texts")),
     )
-    set_span_attributes(span, "db.chroma.query.n_results", kwargs.get("n_results"))
-    set_span_attributes(
+    set_span_attribute(span, "db.chroma.query.n_results", kwargs.get("n_results"))
+    set_span_attribute(
         span, "db.chroma.query.where", handle_null_params(kwargs.get("where"))
     )
-    set_span_attributes(
+    set_span_attribute(
         span,
         "db.chroma.query.where_document",
         handle_null_params(kwargs.get("where_document")),
     )
-    set_span_attributes(
+    set_span_attribute(
         span, "db.chroma.query.include", handle_null_params(kwargs.get("include"))
     )
 
 
 @silently_fail
 def _set_chroma_peek_attributes(span, kwargs):
-    set_span_attributes(span, "db.chroma.peek.limit", kwargs.get("limit"))
+    set_span_attribute(span, "db.chroma.peek.limit", kwargs.get("limit"))
 
 
 @silently_fail
 def _set_chroma_update_attributes(span, kwargs):
-    set_span_attributes(
+    set_span_attribute(
         span, "db.chroma.update.ids_count", get_count_or_none(kwargs.get("ids"))
     )
-    set_span_attributes(
+    set_span_attribute(
         span,
         "db.chroma.update.embeddings_count",
         get_count_or_none(kwargs.get("embeddings")),
     )
-    set_span_attributes(
+    set_span_attribute(
         span,
         "db.chroma.update.metadatas_count",
         get_count_or_none(kwargs.get("metadatas")),
     )
-    set_span_attributes(
+    set_span_attribute(
         span,
         "db.chroma.update.documents_count",
         get_count_or_none(kwargs.get("documents")),
@@ -210,23 +214,23 @@ def _set_chroma_update_attributes(span, kwargs):
 
 @silently_fail
 def _set_chroma_modify_attributes(span, kwargs):
-    set_span_attributes(span, "db.chroma.modify.name", kwargs.get("name"))
+    set_span_attribute(span, "db.chroma.modify.name", kwargs.get("name"))
     # TODO: Add metadata attribute
 
 
 @silently_fail
 def _set_chroma_upsert_attributes(span, kwargs):
-    set_span_attributes(
+    set_span_attribute(
         span,
         "db.chroma.upsert.embeddings_count",
         get_count_or_none(kwargs.get("embeddings")),
     )
-    set_span_attributes(
+    set_span_attribute(
         span,
         "db.chroma.upsert.metadatas_count",
         get_count_or_none(kwargs.get("metadatas")),
     )
-    set_span_attributes(
+    set_span_attribute(
         span,
         "db.chroma.upsert.documents_count",
         get_count_or_none(kwargs.get("documents")),
@@ -235,13 +239,13 @@ def _set_chroma_upsert_attributes(span, kwargs):
 
 @silently_fail
 def _set_chroma_delete_attributes(span, kwargs):
-    set_span_attributes(
+    set_span_attribute(
         span, "db.chroma.delete.ids_count", get_count_or_none(kwargs.get("ids"))
     )
-    set_span_attributes(
+    set_span_attribute(
         span, "db.chroma.delete.where", handle_null_params(kwargs.get("where"))
     )
-    set_span_attributes(
+    set_span_attribute(
         span,
         "db.chroma.delete.where_document",
         handle_null_params(kwargs.get("where_document")),
