@@ -55,7 +55,7 @@ def images_generate(original_method, version, tracer):
         service_provider = SERVICE_PROVIDERS["OPENAI"]
         span_attributes = {
             **get_langtrace_attributes(version, service_provider, vendor_type="llm"),
-            **get_llm_request_attributes(kwargs),
+            **get_llm_request_attributes(kwargs, operation_name="images_generate"),
             **get_llm_url(instance),
             SpanAttributes.LLM_PATH: APIS["IMAGES_GENERATION"]["ENDPOINT"],
             **get_extra_attributes(),
@@ -118,7 +118,7 @@ def async_images_generate(original_method, version, tracer):
 
         span_attributes = {
             **get_langtrace_attributes(version, service_provider, vendor_type="llm"),
-            **get_llm_request_attributes(kwargs),
+            **get_llm_request_attributes(kwargs, operation_name="images_generate"),
             **get_llm_url(instance),
             SpanAttributes.LLM_PATH: APIS["IMAGES_GENERATION"]["ENDPOINT"],
             **get_extra_attributes(),
@@ -181,7 +181,7 @@ def images_edit(original_method, version, tracer):
 
         span_attributes = {
             **get_langtrace_attributes(version, service_provider, vendor_type="llm"),
-            **get_llm_request_attributes(kwargs),
+            **get_llm_request_attributes(kwargs, operation_name="images_edit"),
             **get_llm_url(instance),
             SpanAttributes.LLM_PATH: APIS["IMAGES_EDIT"]["ENDPOINT"],
             SpanAttributes.LLM_RESPONSE_FORMAT: kwargs.get("response_format"),
@@ -294,7 +294,7 @@ def chat_completions_create(original_method, version, tracer):
                 prompt_tokens = 0
                 for message in kwargs.get("messages", {}):
                     prompt_tokens += calculate_prompt_tokens(
-                        json.dumps(message), kwargs.get("model")
+                        json.dumps(str(message)), kwargs.get("model")
                     )
 
                 if (
@@ -388,7 +388,7 @@ def async_chat_completions_create(original_method, version, tracer):
                 prompt_tokens = 0
                 for message in kwargs.get("messages", {}):
                     prompt_tokens += calculate_prompt_tokens(
-                        json.dumps(message), kwargs.get("model")
+                        json.dumps((str(message))), kwargs.get("model")
                     )
 
                 if (
@@ -432,7 +432,7 @@ def embeddings_create(original_method, version, tracer):
 
         span_attributes = {
             **get_langtrace_attributes(version, service_provider, vendor_type="llm"),
-            **get_llm_request_attributes(kwargs),
+            **get_llm_request_attributes(kwargs, operation_name="embed"),
             **get_llm_url(instance),
             SpanAttributes.LLM_PATH: APIS["EMBEDDINGS_CREATE"]["ENDPOINT"],
             SpanAttributes.LLM_REQUEST_DIMENSIONS: kwargs.get("dimensions"),
@@ -490,7 +490,7 @@ def async_embeddings_create(original_method, version, tracer):
 
         span_attributes = {
             **get_langtrace_attributes(version, service_provider, vendor_type="llm"),
-            **get_llm_request_attributes(kwargs),
+            **get_llm_request_attributes(kwargs, operation_name="embed"),
             SpanAttributes.LLM_PATH: APIS["EMBEDDINGS_CREATE"]["ENDPOINT"],
             SpanAttributes.LLM_REQUEST_DIMENSIONS: kwargs.get("dimensions"),
             **get_extra_attributes(),
@@ -582,12 +582,11 @@ def extract_content(choice):
 
 @silently_fail
 def _set_input_attributes(span, kwargs, attributes):
-
+    tools = []
     for field, value in attributes.model_dump(by_alias=True).items():
         set_span_attribute(span, field, value)
 
     if kwargs.get("functions") is not None and kwargs.get("functions") != NOT_GIVEN:
-        tools = []
         for function in kwargs.get("functions"):
             tools.append(json.dumps({"type": "function", "function": function}))
 
